@@ -195,16 +195,16 @@ get_exif_time (const char *uri)
 	if (local_file == NULL)
                 return (time_t) 0;
 
-        gth_minimal_exif_tag_read (local_file, EXIF_TAG_DATE_TIME, date_string, 20);
+        gth_minimal_exif_tag_read (local_file, EXIF_TAG_DATE_TIME_ORIGINAL, date_string, 20);
 	time = exif_string_to_time_t (date_string);
 
 	if (time <= (time_t) 0) {
-		gth_minimal_exif_tag_read (local_file, EXIF_TAG_DATE_TIME_ORIGINAL, date_string, 20);
+		gth_minimal_exif_tag_read (local_file, EXIF_TAG_DATE_TIME_DIGITIZED, date_string, 20);
 		time = exif_string_to_time_t (date_string);
 	}
 
 	if (time <= (time_t) 0) {
-		gth_minimal_exif_tag_read (local_file, EXIF_TAG_DATE_TIME_DIGITIZED, date_string, 20);
+		gth_minimal_exif_tag_read (local_file, EXIF_TAG_DATE_TIME, date_string, 20);
 		time = exif_string_to_time_t (date_string);
 	}
 
@@ -353,6 +353,26 @@ const char types[] = {0x00, 0x01, 0x01, 0x02, 0x04, 0x08, 0x00, 0x08, 0x00, 0x04
 #define IFD_NAME_PUSH(val) names[ni++] = val;
 #define IFD_NAME_PULL()    names[--ni]
 
+static unsigned short de_get16(void *ptr, guint endian)
+{
+	unsigned short val;
+
+	memcpy(&val, ptr, sizeof(val));
+	val = DE_ENDIAN16(val);
+
+	return val;
+}
+
+static unsigned int de_get32(void *ptr, guint endian)
+{
+	unsigned int val;
+
+	memcpy(&val, ptr, sizeof(val));
+	val = DE_ENDIAN32(val);
+
+	return val;
+}
+
 int static
 gth_minimal_exif_tag_action (const char *local_file,
 			     ExifTag     etag,
@@ -392,7 +412,10 @@ gth_minimal_exif_tag_action (const char *local_file,
  	int           cifdi = 0;    // curret ifd index
  
  	debug (DEBUG_INFO, "gth_minimal_exif_tag_access (%s, %04x, %08x, %d)\n", local_file, etag, data, size);
- 
+
+	// local files only
+	g_assert (uri_has_scheme (local_file) == FALSE);
+
         // Init IFD stack
  	IFD_OFFSET_PUSH(0);
  	IFD_NAME_PUSH("START");
@@ -409,15 +432,15 @@ gth_minimal_exif_tag_action (const char *local_file,
  
         // Check for TIFF header and catch endianess
  	i = 0;
- 	while (i < readsize){
+ 	while (i < readsize) {
  
  		// Little endian TIFF header
- 		if (bcmp (&buf[i], leth, 4) == 0){ 
+ 		if (bcmp (&buf[i], leth, 4) == 0) { 
  			endian = G_LITTLE_ENDIAN;
                 }
  
  		// Big endian TIFF header
- 		else if (bcmp (&buf[i], beth, 4) == 0){ 
+ 		else if (bcmp (&buf[i], beth, 4) == 0) { 
  			endian = G_BIG_ENDIAN;
                 }
  
@@ -440,7 +463,7 @@ gth_minimal_exif_tag_action (const char *local_file,
         tag     = ENDIAN16_IT(etag);
  
         // Read out the offset
-        offset  = DE_ENDIAN32(*((unsigned long*)(&buf[i] + 4)));
+        offset  = de_get32(&buf[i] + 4, endian);
  	i       = i + offset;
  
         // Start out with IFD0 (and add more IFDs while we go)
@@ -448,38 +471,38 @@ gth_minimal_exif_tag_action (const char *local_file,
  	IFD_NAME_PUSH("IFD0");
  
         // As long as we find more IFDs check out the tags in each
- 	while ((oi >=0 && (i = IFD_OFFSET_PULL()) != 0 && i < readsize - 2)){
+ 	while ((oi >=0 && (i = IFD_OFFSET_PULL()) != 0 && i < readsize - 2)) {
  	  
  		cifdi    = oi; // remember which ifd we are at
  
  		debug (DEBUG_INFO, "%s:\n", IFD_NAME_PULL());
- 		tags    = DE_ENDIAN16(*((unsigned short*)(&buf[i])));
+ 		tags    = de_get16(&buf[i], endian);
  		i       = i + 2;
  
  		// Check this IFD for tags of interest
  		while (tags-- && i < readsize - 12) {
- 			type   = DE_ENDIAN16(*((unsigned short*)(&buf[i + 2])));
- 			count  = DE_ENDIAN32(*((unsigned long*) (&buf[i + 4])));
- 			offset = DE_ENDIAN32(*((unsigned long*) (&buf[i + 8])));
+ 			type   = de_get16(&buf[i + 2], endian);
+ 			count  = de_get32(&buf[i + 4], endian);
+ 			offset = de_get32(&buf[i + 8], endian);
  
  			debug (DEBUG_INFO, "TAG: %04x type:%02d count:%02d offset:%04lx ", 
- 				     DE_ENDIAN16(*((unsigned short*)(&buf[i]))), type, count, offset);
+			       de_get16(&buf[i], endian), type, count, offset);
  
  			// Our tag?
- 			if (bcmp (&buf[i], (char *)&tag, 2) == 0){ 
+ 			if (bcmp (&buf[i], (char *)&tag, 2) == 0) { 
  
 				// Write TAG value
-				if (access == 1){ 
+				if (access == 1) { 
 
 					// Local value that can be patched directly in TAG table 
-					if ((types[type] * count) <= 4){
+					if ((types[type] * count) <= 4) {
  
 						// Fake TIFF offset
 						offset = i + 8 - tiff; 
 						patches++;
 					}
 					// Offseted value of same or larger size that we can patch
-					else if (types[type] * count >= size){
+					else if (types[type] * count >= size) {
 						
 						// Adjust count to new length
 						count = size / types[type]; 
@@ -497,8 +520,8 @@ gth_minimal_exif_tag_action (const char *local_file,
 
 					// Copy the data
 					stitch = 0;
-					while (stitch < count){
-						switch (types[type]){
+					while (stitch < count) {
+						switch (types[type]) {
 						case 1:
 							buf[tiff + offset + stitch] = *(char *) (data + stitch);
 							break;
@@ -548,12 +571,12 @@ gth_minimal_exif_tag_action (const char *local_file,
 							break;
 						case 2:
 							*(guint16 *) (data + stitch * 2) = 
-								DE_ENDIAN16(*((unsigned short*)(&buf[tiff + offset + stitch * 2])));
+								de_get16(&buf[tiff + offset + stitch * 2], endian);
 							
 							break;
 						case 4:
 							*(guint32 *) (data + stitch * 4) =
-								DE_ENDIAN32(*((unsigned long*) (&buf[tiff + offset + stitch * 4])));
+								de_get32(&buf[tiff + offset + stitch * 4], endian);
 							
 							break;
 						default:
@@ -566,12 +589,12 @@ gth_minimal_exif_tag_action (const char *local_file,
 				}
 			}
  			// EXIF pointer tag?
- 			else if (bcmp (&buf[i], (char *) &exififd, 2) == 0){ 
+ 			else if (bcmp (&buf[i], (char *) &exififd, 2) == 0) { 
  				IFD_OFFSET_PUSH(offset + tiff);
  				IFD_NAME_PUSH("EXIF");
  			}
  			// GPS pointer tag?
- 			else if (bcmp (&buf[i], (char *) &gpsifd, 2) == 0){ 
+ 			else if (bcmp (&buf[i], (char *) &gpsifd, 2) == 0) { 
  				IFD_OFFSET_PUSH(offset + tiff);
  				IFD_NAME_PUSH("GPS");
  			}
@@ -582,7 +605,7 @@ gth_minimal_exif_tag_action (const char *local_file,
  		}
 
  		// Check for a valid next pointer and assume that to be IFD1 if we just checked IFD0
- 		if (cifdi == 1 && i < readsize - 2 && (i = DE_ENDIAN32((*((unsigned long*) (&buf[i]))))) != 0){ 
+ 		if (cifdi == 1 && i < readsize - tiff && (i = de_get32(&buf[i], endian)) != 0) { 
  			i = i + tiff;
  			IFD_OFFSET_PUSH(i);
  			IFD_NAME_PUSH("IFD1");
