@@ -67,7 +67,7 @@ gth_dir_list_finalize (GObject *object)
         g_return_if_fail (GTH_IS_DIR_LIST (object));
 	dir_list = GTH_DIR_LIST (object);
 
-	path_list_free (dir_list->file_list);
+	file_data_list_free (dir_list->file_list);
 	path_list_free (dir_list->list);
 	g_free (dir_list->path);
 	g_free (dir_list->try_path);
@@ -360,6 +360,14 @@ gth_dir_list_new (void)
 }
 
 
+void
+gth_dir_list_show_hidden_files (GthDirList  *dir_list,
+	     		        gboolean     show)
+{
+	dir_list->show_dot_files = show;
+}
+
+
 void
 gth_dir_list_update_underline (GthDirList *dir_list)
 {
@@ -516,7 +524,7 @@ gth_dir_list_change_to__step2 (PathListData *pld,
 
 	/* Set the new file list. */
 
-	path_list_free (dir_list->file_list);
+	file_data_list_free (dir_list->file_list);
 	dir_list->file_list = new_file_list;
 
 	/* Set the new dir list */
@@ -526,7 +534,7 @@ gth_dir_list_change_to__step2 (PathListData *pld,
 					     eel_gconf_get_boolean (PREF_SHOW_HIDDEN_FILES, DEF_SHOW_HIDDEN));
 
 	/* * Add the ".." entry if the current path is not "/".
-	 * path_list_new does not include the "." and ".." elements. */
+	 * path_list_async_new does not include the "." and ".." elements. */
 
 	if (! uri_is_root (dir_list->path))
 		filtered = g_list_prepend (filtered, g_strdup (".."));
@@ -575,6 +583,16 @@ gth_dir_list_change_to__step2 (PathListData *pld,
 }
 
 
+static gboolean 
+gth_dir_list_filter_func (PathListData  *pld, 
+			  FileData      *file, 
+			  gpointer       data)
+{
+	GthDirList *dir_list = data;
+	return file_filter (file, dir_list->show_dot_files);
+}
+
+
 void
 gth_dir_list_change_to (GthDirList *dir_list,
 		        const char *path)
@@ -590,7 +608,13 @@ gth_dir_list_change_to (GthDirList *dir_list,
 	if (dir_list->dir_load_handle != NULL)
 		path_list_async_interrupt (dir_list->dir_load_handle, NULL, NULL);
 
-	dir_list->dir_load_handle = path_list_async_new (dir_list->try_path, gth_dir_list_change_to__step2, dir_list);
+	dir_list->dir_load_handle = path_list_async_new (
+		dir_list->try_path, 
+		gth_dir_list_filter_func, 
+		dir_list, 
+		eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE),
+		gth_dir_list_change_to__step2, 
+		dir_list);
 }
 
 
@@ -854,5 +878,5 @@ GList *
 gth_dir_list_get_file_list (GthDirList *dir_list)
 {
 	g_return_val_if_fail (dir_list != NULL, NULL);
-	return path_list_dup (dir_list->file_list);
+	return file_data_list_dup (dir_list->file_list);
 }
